@@ -85,7 +85,8 @@ class ASCIINemaDirective(SphinxDirective):
             node.cast_file = self.add_file(arg)
         else:
             node.cast_id = arg
-        node.options = self.env.config['sphinxcontrib_asciinema_defaults']
+        # copy default options, otherwise reference is shared between all nodes
+        node.options = dict(self.env.config['sphinxcontrib_asciinema_defaults'])
         node.options.update(self.options)
         return [node]
 
@@ -102,7 +103,7 @@ class ASCIINemaDirective(SphinxDirective):
         copy_asset(file_path, target_dir)
 
         # Determine relative path from doc to _asset build path.
-        target_file_uri = posixpath.join('_casts', md5_hash, rel_file)
+        target_file_uri = posixpath.join('_casts', md5_hash, os.path.basename(rel_file))
         try:
             doc_uri = self.env.app.builder.get_target_uri(self.env.docname)
             return relative_uri(doc_uri, target_file_uri)
